@@ -77,7 +77,7 @@ console = Console()
 
 
 async def get_languages() -> Dict[Text, Any]:
-    logger.debug("Fetching all supported languages for NLU")
+    console.print("> [deep_sky_blue2]INFO[/deep_sky_blue2] ⬇️ Fetching all supported languages for NLU")
     HEADERS = copy(COMMON_HEADERS)
     HEADERS[AUTHORIZATION] = get_auth_token()
     async with get_async_http_session().get(
@@ -86,11 +86,11 @@ async def get_languages() -> Dict[Text, Any]:
     ) as response:
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
-            logger.debug("Successfully created project")
-            logger.info(f"{json.dumps(json_response, indent=4)}")
+            console.print("> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Successfully created project")
+            console.print(f"{json.dumps(json_response, indent=4)}")
         else:
-            logger.error("Failed to create project")
-            logger.error(f"Platform response: \n {json.dumps(json_response, indent=4)}")
+            logger.error("> [red]ERROR[/red] ❌ Failed to create project")
+            logger.error(f"😔 Platform response: \n{json.dumps(json_response, indent=4)}")
     return json_response
 
 
@@ -144,13 +144,13 @@ async def create_project(project_name: Text, languages: List[Text]) -> Dict[Text
                 f" [dark_orange3]{UPLOAD_DATASET_COMMAND}[/dark_orange3]"
             )
         else:
-            console.print("> [red]ERROR[/red] Failed ❌  to create project")
+            console.print("> [red]ERROR[/red] ❌ Failed to create project")
             console.print(f"> 😔[red]{json_response[DATA]['error']}[/red]")
     return json_response
 
 
 async def delete_project(project_id: Text) -> Dict[Text, Any]:
-    logger.info(f"Deleting project with id: {project_id}")
+    console.print(f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🗑️ Deleting project with id: {project_id}")
     payload = {PROJECT_ID: project_id}
     HEADERS = copy(COMMON_HEADERS)
     HEADERS[AUTHORIZATION] = get_auth_token()
@@ -161,10 +161,10 @@ async def delete_project(project_id: Text) -> Dict[Text, Any]:
     ) as response:
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
-            logger.info(f"Platform Response: \n{json.dumps(json_response, indent=4)}")
+            console.print("> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Successfully deleted project")
         else:
-            logger.error("Failed to delete projects")
-            logger.error(f"Platform response: \n {json.dumps(json_response, indent=4)}")
+            logger.error("> [red]ERROR[/red] ❌ Failed to delete projects")
+            logger.error(f"😔 Platform response: \n{json.dumps(json_response, indent=4)}")
     return json_response
 
 
@@ -180,9 +180,9 @@ def print_projects_table(projects: Dict[Text, Any]):
         table.add_row(
                 data[PROJECT_NAME],
                 data[PROJECT_ID],
-                data[NUMBER_OF_EXAMPLES],
-                data[NUMBER_OF_INTENTS],
-                data[NUMBER_OF_MODELS],
+                str(data[NUMBER_OF_EXAMPLES]),
+                str(data[NUMBER_OF_INTENTS]),
+                str(data[NUMBER_OF_MODELS]),
                 data[LANGUAGE]
         )
     console.print(table)
@@ -209,7 +209,7 @@ def train_table(projects: Dict[Text, Any]):
                 data[LANGUAGE],
             ]
         )
-    logger.info(f"\n{table}")
+    console.print(f"\n{table}")
 
 
 async def list_projects(
@@ -247,7 +247,7 @@ def print_examples_table(examples: Dict[Text, Any]):
     table.add_column("Intent", style="#c47900")
     table.add_column("N Entities", style="#c47900")
 
-    logger.info(f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🔢 Total Examples Count: {examples[DATA][COUNT]}")
+    console.print(f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🔢 Total Examples Count: {examples[DATA][COUNT]}")
     for data in examples[DATA][EXAMPLES]:
         text = data[TEXT][:20]
         if len(data[TEXT]) > 20:
@@ -328,7 +328,7 @@ def print_models_table(models: Dict[Text, Any]):
     table.add_column("Last Updated", style="#c47900")
 
     console.print(f"> Total Models Count: {models[DATA][COUNT]}")
-    logger.info(f" [deep_sky_blue2]INFO[/deep_sky_blue2] 🔢 Total Models Count: {models[DATA][COUNT]}")
+    console.print(f" [deep_sky_blue2]INFO[/deep_sky_blue2] 🔢 Total Models Count: {models[DATA][COUNT]}")
     for data in models[DATA][MODELS]:
         table.add_row(
 
@@ -564,7 +564,7 @@ async def delete_models(model_id: Text) -> Dict[Text, Any]:
 
 
 async def deploy(model_id: Text, n_replicas: int) -> Dict[Text, Any]:
-    logger.info(f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ⤴️ Deploying: Model ID: {model_id}; Replicas: {n_replicas};")
+    console.print(f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ⤴️ Deploying: Model ID: {model_id}; Replicas: {n_replicas};")
     payload = {MODEL_ID: model_id, N_REPLICAS: n_replicas}
     HEADERS = copy(COMMON_HEADERS)
     HEADERS[AUTHORIZATION] = get_auth_token()
@@ -576,11 +576,11 @@ async def deploy(model_id: Text, n_replicas: int) -> Dict[Text, Any]:
     ) as response:
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
-            logger.info("> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Model deployed successfully")
-            logger.info(f"> [deep_sky_blue2]INFO[/deep_sky_blue2] Platform Response: \n{json.dumps(json_response, indent=4)}")
+            console.print("> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Model deployed successfully")
+            console.print(f"> [deep_sky_blue2]INFO[/deep_sky_blue2] Platform Response: \n{json.dumps(json_response, indent=4)}")
         else:
-            logger.error("> [red]ERROR[/red] ❌ Failed to deploy model")
-            logger.error(f"> Platform response: \n{json.dumps(json_response, indent=4)}")
+            console.print("> [red]ERROR[/red] ❌ Failed to deploy model")
+            console.print(f"> Platform response: \n{json.dumps(json_response, indent=4)}")
     return json_response
 
 
@@ -635,6 +635,6 @@ async def parse(model_id: Text, input_text: Text) -> Dict[Text, Any]:
             console.print("> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Successfully parsed text")
             print_nlu_response(json_response, response_time)
         else:
-            logger.error("> [red]ERROR[/red] ❌ Failed to parse model")
-            logger.error(f"> Platform response: \n{json.dumps(json_response, indent=4)}")
+            console.print("> [red]ERROR[/red] ❌ Failed to parse model")
+            console.print(f"> Platform response: \n{json.dumps(json_response, indent=4)}")
     return json_response
