@@ -95,7 +95,7 @@ async def do_login(email: Text, password: Text):
                 f"⏩  Install an app: [dark_orange3]{INSTALL_APP_COMMAND}[/dark_orange3]"
             )
         else:
-            console.print("Login failed ❌! Please check your username and password")
+            console.print("> [red]ERROR[/red] ❌ Login failed! Please check your username and password")
 
 
 async def app_install(name: Text):
@@ -120,7 +120,7 @@ async def app_install(name: Text):
                     f"> [deep_sky_blue2]INFO[/deep_sky_blue2] [dark_orange3]{APP_IS_INSTALLED}[/dark_orange3]"
                 )
             else:
-                console.print(" ❌ Install Failed!")
+                console.print("> [red]ERROR[/red] ❌ Install Failed!")
                 console.print(
                     f"\n{json.dumps(json_response, indent=4, ensure_ascii=False)}"
                 )
@@ -196,8 +196,7 @@ def print_logo_and_description():
     console.print(table)
 
 
-def print_ner_response(response: Dict[Text, Text], original_text: Text):
-    list_of_entities = response["data"]["entities"]
+def print_ner_response(list_of_entities: List[Dict[Text, Text]], original_text: Text):
     if not list_of_entities:
         console.print(
             f"There is no entities in your text: [bold red]{original_text}[/bold red]"
